@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl -w
 
-require 5.000;
+require 5.004; # or use CLex.pl
 
 BEGIN {		
   push(@INC,  ("$ENV{'HOME'}/lib/perl5")); # or PERL5LIB
@@ -32,7 +32,7 @@ print "Tokenization of DATA:\n";
 TOKEN:while (1) {
   $token = $lexer->next;
   if (not $lexer->eoi) {
-    print "Line $.\t";
+    print "Record number: ", $lexer->recordno, "\n";
     print "Type: ", $token->name, "\t";
     print "Content:->", $token->getstring, "<-\n";
   } else {
